"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const api_1 = require("../../../api");
const CicsBaseHandler_1 = require("../../CicsBaseHandler");
// Does not use the import in anticipation of some internationalization work to be done later.
const strings = require("../../-strings-/en").default.DEFINE.RESOURCES.PROGRAM;
/**
 * Command handler for defining CICS programs via CMCI
 * @export
 * @class ProgramHandler
 * @implements {ICommandHandler}
 */
class ProgramHandler extends CicsBaseHandler_1.CicsBaseHandler {
    processWithSession(params, session, profile) {
        return __awaiter(this, void 0, void 0, function* () {
            const status = {
                statusMessage: "Defining program to CICS",
                percentComplete: 0,
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            params.response.progress.startBar({ task: status });
            const response = yield (0, api_1.defineProgram)(session, {
                name: params.arguments.programName,
                csdGroup: params.arguments.csdGroup,
                regionName: params.arguments.regionName || profile.regionName,
                cicsPlex: params.arguments.cicsPlex || profile.cicsPlex
            });
            params.response.console.log(strings.MESSAGES.SUCCESS, params.arguments.programName);
            return response;
        });
    }
}
exports.default = ProgramHandler;
//# sourceMappingURL=Program.handler.js.map