"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const index_1 = require("../../../index");
const fs = require("fs");
/**
 * Command handler for executing of SQL queries
 * @export
 * @class SQLHandler
 * @implements {ICommandHandler}
 */
class SQLHandler extends index_1.DB2BaseHandler {
    processWithDB2Session(params, session) {
        return __awaiter(this, void 0, void 0, function* () {
            const DB2session = session.ISession;
            let query;
            if (params.arguments.file) {
                try {
                    query = fs.readFileSync(params.arguments.file, "utf-8").toString();
                }
                catch (err) {
                    throw new imperative_1.ImperativeError({ msg: err.toString() });
                }
            }
            else {
                query = params.arguments.query;
            }
            const executor = new index_1.ExecuteSQL(DB2session);
            const response = executor.execute(query);
            const responses = [];
            let result;
            let resultset = 1;
            // Print out the response
            while (!(result = response.next()).done) {
                responses.push(result.value);
                params.response.console.log(`Result #${resultset}`);
                params.response.console.log(imperative_1.TextUtils.prettyJson(result.value));
                resultset++;
            }
            // Return as an object when using --response-format-json
            params.response.data.setObj(responses);
        });
    }
}
exports.default = SQLHandler;
//# sourceMappingURL=SQL.handler.js.map